@@ -8,6 +8,7 @@ use crate::modules;
 use crate::utils;
 use clap::Parser;
 use gix::{
+    repository::Kind,
     sec::{self as git_sec, trust::DefaultForLevel},
     state as git_state, Repository, ThreadSafeRepository,
 };
@@ -235,8 +236,32 @@ impl<'a> Context<'a> {
         disabled == Some(true)
     }
 
+    /// Returns true when a negated environment variable is defined in `env_vars` and is present
+    fn has_negated_env_var(&self, env_vars: &'a [&'a str]) -> bool {
+        env_vars
+            .iter()
+            .filter_map(|env_var| env_var.strip_prefix('!'))
+            .any(|env_var| self.get_env(env_var).is_some())
+    }
+
+    /// Returns true if 'detect_env_vars' is empty,
+    /// or if at least one environment variable is set and no negated environment variable is set
     pub fn detect_env_vars(&'a self, env_vars: &'a [&'a str]) -> bool {
-        env_vars.is_empty() || (env_vars.iter().any(|e| self.get_env(e).is_some()))
+        if env_vars.is_empty() {
+            return true;
+        }
+
+        if self.has_negated_env_var(env_vars) {
+            return false;
+        }
+
+        // Returns true if at least one environment variable is set
+        let mut iter = env_vars
+            .iter()
+            .filter(|env_var| !env_var.starts_with('!'))
+            .peekable();
+
+        iter.peek().is_none() || iter.any(|env_var| self.get_env(env_var).is_some())
     }
 
     // returns a new ScanDir struct with reference to current dir_files of context
@@ -313,6 +338,12 @@ impl<'a> Context<'a> {
                 let branch = get_current_branch(&repository);
                 let remote = get_remote_repository_info(&repository, branch.as_deref());
                 let path = repository.path().to_path_buf();
+
+                let fs_monitor_value_is_true = repository
+                    .config_snapshot()
+                    .boolean("core.fs_monitor")
+                    .unwrap_or(false);
+
                 Ok(Repo {
                     repo: shared_repo,
                     branch,
@@ -320,6 +351,8 @@ impl<'a> Context<'a> {
                     path,
                     state: repository.state(),
                     remote,
+                    fs_monitor_value_is_true,
+                    kind: repository.kind(),
                 })
             })
     }
@@ -327,7 +360,11 @@ impl<'a> Context<'a> {
     pub fn dir_contents(&self) -> Result<&DirContents, std::io::Error> {
         self.dir_contents.get_or_try_init(|| {
             let timeout = self.root_config.scan_timeout;
-            DirContents::from_path_with_timeout(&self.current_dir, Duration::from_millis(timeout))
+            DirContents::from_path_with_timeout(
+                &self.current_dir,
+                Duration::from_millis(timeout),
+                self.root_config.follow_symlinks,
+            )
         })
     }
 
@@ -337,7 +374,8 @@ impl<'a> Context<'a> {
             "bash" => Shell::Bash,
             "fish" => Shell::Fish,
             "ion" => Shell::Ion,
-            "powershell" | "pwsh" => Shell::PowerShell,
+            "pwsh" => Shell::Pwsh,
+            "powershell" => Shell::PowerShell,
             "zsh" => Shell::Zsh,
             "elvish" => Shell::Elvish,
             "tcsh" => Shell::Tcsh,
@@ -448,11 +486,15 @@ pub struct DirContents {
 
 impl DirContents {
     #[cfg(test)]
-    fn from_path(base: &Path) -> Result<Self, std::io::Error> {
-        Self::from_path_with_timeout(base, Duration::from_secs(30))
+    fn from_path(base: &Path, follow_symlinks: bool) -> Result<Self, std::io::Error> {
+        Self::from_path_with_timeout(base, Duration::from_secs(30), follow_symlinks)
     }
 
-    fn from_path_with_timeout(base: &Path, timeout: Duration) -> Result<Self, std::io::Error> {
+    fn from_path_with_timeout(
+        base: &Path,
+        timeout: Duration,
+        follow_symlinks: bool,
+    ) -> Result<Self, std::io::Error> {
         let start = Instant::now();
 
         let mut folders: HashSet<PathBuf> = HashSet::new();
@@ -470,7 +512,15 @@ impl DirContents {
             .filter_map(|(_, entry)| entry.ok())
             .for_each(|entry| {
                 let path = PathBuf::from(entry.path().strip_prefix(base).unwrap());
-                if entry.path().is_dir() {
+
+                let is_dir = match follow_symlinks {
+                    true => entry.path().is_dir(),
+                    false => fs::symlink_metadata(entry.path())
+                        .map(|m| m.is_dir())
+                        .unwrap_or(false),
+                };
+
+                if is_dir {
                     folders.insert(path);
                 } else {
                     if !path.to_string_lossy().starts_with('.') {
@@ -589,6 +639,13 @@ pub struct Repo {
 
     /// Remote repository
     pub remote: Option<Remote>,
+
+    /// Contains `true` if the value of `core.fsmonitor` is set to `true`.
+    /// If not `true`, `fsmonitor` is explicitly disabled in git commands.
+    fs_monitor_value_is_true: bool,
+
+    // Kind of repository, work tree or bare
+    pub kind: Kind,
 }
 
 impl Repo {
@@ -596,6 +653,47 @@ impl Repo {
     pub fn open(&self) -> Repository {
         self.repo.to_thread_local()
     }
+
+    /// Wrapper to execute external git commands.
+    /// Handles adding the appropriate `--git-dir` and `--work-tree` flags to the command.
+    /// Also handles additional features required for security, such as disabling `fsmonitor`.
+    /// At this time, mocking is not supported.
+    pub fn exec_git<T: AsRef<OsStr> + Debug>(
+        &self,
+        context: &Context,
+        git_args: &[T],
+    ) -> Option<CommandOutput> {
+        let mut command = create_command("git").ok()?;
+
+        // A value of `true` should not execute external commands.
+        let fsm_config_value = if self.fs_monitor_value_is_true {
+            "core.fsmonitor=true"
+        } else {
+            "core.fsmonitor="
+        };
+
+        command.env("GIT_OPTIONAL_LOCKS", "0").args([
+            OsStr::new("-C"),
+            context.current_dir.as_os_str(),
+            OsStr::new("--git-dir"),
+            self.path.as_os_str(),
+            OsStr::new("-c"),
+            OsStr::new(fsm_config_value),
+        ]);
+
+        // Bare repositories might not have a workdir, so we need to check for that.
+        if let Some(wt) = self.workdir.as_ref() {
+            command.args([OsStr::new("--work-tree"), wt.as_os_str()]);
+        }
+
+        command.args(git_args);
+        log::trace!("Executing git command: {:?}", command);
+
+        exec_timeout(
+            &mut command,
+            Duration::from_millis(context.root_config.command_timeout),
+        )
+    }
 }
 
 /// Remote repository
@@ -718,6 +816,7 @@ pub enum Shell {
     Bash,
     Fish,
     Ion,
+    Pwsh,
     PowerShell,
     Zsh,
     Elvish,
@@ -821,10 +920,63 @@ mod tests {
         Ok(dir)
     }
 
+    #[test]
+    fn test_scan_dir_no_symlinks() -> Result<(), Box<dyn std::error::Error>> {
+        #[cfg(not(target_os = "windows"))]
+        use std::os::unix::fs::symlink;
+        #[cfg(target_os = "windows")]
+        use std::os::windows::fs::symlink_dir as symlink;
+
+        let d = testdir(&["file"])?;
+        fs::create_dir(d.path().join("folder"))?;
+
+        symlink(d.path().join("folder"), d.path().join("link_to_folder"))?;
+        symlink(d.path().join("file"), d.path().join("link_to_file"))?;
+
+        let dc_following_symlinks = DirContents::from_path(d.path(), true)?;
+
+        assert!(ScanDir {
+            dir_contents: &dc_following_symlinks,
+            files: &["link_to_file"],
+            extensions: &[],
+            folders: &[],
+        }
+        .is_match());
+
+        assert!(ScanDir {
+            dir_contents: &dc_following_symlinks,
+            files: &[],
+            extensions: &[],
+            folders: &["link_to_folder"],
+        }
+        .is_match());
+
+        let dc_not_following_symlinks = DirContents::from_path(d.path(), false)?;
+
+        assert!(ScanDir {
+            dir_contents: &dc_not_following_symlinks,
+            files: &["link_to_file"],
+            extensions: &[],
+            folders: &[],
+        }
+        .is_match());
+
+        assert!(!ScanDir {
+            dir_contents: &dc_not_following_symlinks,
+            files: &[],
+            extensions: &[],
+            folders: &["link_to_folder"],
+        }
+        .is_match());
+
+        Ok(())
+    }
+
     #[test]
     fn test_scan_dir() -> Result<(), Box<dyn std::error::Error>> {
         let empty = testdir(&[])?;
-        let empty_dc = DirContents::from_path(empty.path())?;
+        let follow_symlinks = true;
+        let empty_dc = DirContents::from_path(empty.path(), follow_symlinks)?;
 
         assert!(!ScanDir {
             dir_contents: &empty_dc,
@@ -836,7 +988,7 @@ mod tests {
         empty.close()?;
 
         let rust = testdir(&["README.md", "Cargo.toml", "src/main.rs"])?;
-        let rust_dc = DirContents::from_path(rust.path())?;
+        let rust_dc = DirContents::from_path(rust.path(), follow_symlinks)?;
         assert!(!ScanDir {
             dir_contents: &rust_dc,
             files: &["package.json"],
@@ -847,7 +999,7 @@ mod tests {
         rust.close()?;
 
         let java = testdir(&["README.md", "src/com/test/Main.java", "pom.xml"])?;
-        let java_dc = DirContents::from_path(java.path())?;
+        let java_dc = DirContents::from_path(java.path(), follow_symlinks)?;
         assert!(!ScanDir {
             dir_contents: &java_dc,
             files: &["package.json"],
@@ -858,7 +1010,7 @@ mod tests {
         java.close()?;
 
         let node = testdir(&["README.md", "node_modules/lodash/main.js", "package.json"])?;
-        let node_dc = DirContents::from_path(node.path())?;
+        let node_dc = DirContents::from_path(node.path(), follow_symlinks)?;
         assert!(ScanDir {
             dir_contents: &node_dc,
             files: &["package.json"],
@@ -869,7 +1021,7 @@ mod tests {
         node.close()?;
 
         let tarballs = testdir(&["foo.tgz", "foo.tar.gz"])?;
-        let tarballs_dc = DirContents::from_path(tarballs.path())?;
+        let tarballs_dc = DirContents::from_path(tarballs.path(), follow_symlinks)?;
         assert!(ScanDir {
             dir_contents: &tarballs_dc,
             files: &[],
@@ -880,7 +1032,7 @@ mod tests {
         tarballs.close()?;
 
         let dont_match_ext = testdir(&["foo.js", "foo.ts"])?;
-        let dont_match_ext_dc = DirContents::from_path(dont_match_ext.path())?;
+        let dont_match_ext_dc = DirContents::from_path(dont_match_ext.path(), follow_symlinks)?;
         assert!(!ScanDir {
             dir_contents: &dont_match_ext_dc,
             files: &[],
@@ -891,7 +1043,7 @@ mod tests {
         dont_match_ext.close()?;
 
         let dont_match_file = testdir(&["goodfile", "evilfile"])?;
-        let dont_match_file_dc = DirContents::from_path(dont_match_file.path())?;
+        let dont_match_file_dc = DirContents::from_path(dont_match_file.path(), follow_symlinks)?;
         assert!(!ScanDir {
             dir_contents: &dont_match_file_dc,
             files: &["goodfile", "!notfound", "!evilfile"],
@@ -902,7 +1054,8 @@ mod tests {
         dont_match_file.close()?;
 
         let dont_match_folder = testdir(&["gooddir/somefile", "evildir/somefile"])?;
-        let dont_match_folder_dc = DirContents::from_path(dont_match_folder.path())?;
+        let dont_match_folder_dc =
+            DirContents::from_path(dont_match_folder.path(), follow_symlinks)?;
         assert!(!ScanDir {
             dir_contents: &dont_match_folder_dc,
             files: &[],
