@@ -8,18 +8,22 @@ use crate::formatter::StringFormatter;
 /// Creates a module with the system hostname
 ///
 /// Will display the hostname if all of the following criteria are met:
-///     - hostname.disabled is absent or false
+///     - `hostname.disabled` is absent or false
 ///     - `hostname.ssh_only` is false OR the user is currently connected as an SSH session (`$SSH_CONNECTION`)
+///     - `hostname.ssh_only` is false AND `hostname.detect_env_vars` is either empty or contains a defined environment variable
 pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     let mut module = context.new_module("hostname");
     let config: HostnameConfig = HostnameConfig::try_load(module.config);
 
     let ssh_connection = context.get_env("SSH_CONNECTION");
-    if config.ssh_only && ssh_connection.is_none() {
+
+    if (config.ssh_only && ssh_connection.is_none())
+        || !context.detect_env_vars(&config.detect_env_vars)
+    {
         return None;
     }
 
-    let os_hostname: OsString = gethostname::gethostname();
+    let os_hostname: OsString = whoami::hostname_os();
 
     let host = match os_hostname.into_string() {
         Ok(host) => host,
@@ -83,7 +87,7 @@ mod tests {
 
     macro_rules! get_hostname {
         () => {
-            if let Ok(hostname) = gethostname::gethostname().into_string() {
+            if let Ok(hostname) = whoami::hostname_os().into_string() {
                 hostname
             } else {
                 println!(
@@ -96,17 +100,82 @@ mod tests {
     }
 
     #[test]
-    fn ssh_only_false_no_ssh() {
+    fn ssh_only_false_with_empty_detect_env_vars() {
         let hostname = get_hostname!();
         let actual = ModuleRenderer::new("hostname")
             .config(toml::toml! {
                 [hostname]
                 ssh_only = false
                 trim_at = ""
+                detect_env_vars = []
             })
             .collect();
+
         let expected = Some(format!("{} in ", style().paint(hostname)));
-        println!("{}", expected.as_ref().unwrap());
+        assert_eq!(expected, actual);
+    }
+
+    #[test]
+    fn ssh_only_false_with_matching_negated_env_var() {
+        let actual = ModuleRenderer::new("hostname")
+            .config(toml::toml! {
+                [hostname]
+                ssh_only = false
+                trim_at = ""
+                detect_env_vars = ["!NEGATED"]
+            })
+            .env("NEGATED", "true")
+            .collect();
+        let expected = None;
+
+        assert_eq!(expected, actual);
+    }
+
+    #[test]
+    fn ssh_only_false_with_only_negated_env_vars() {
+        let hostname = get_hostname!();
+        let actual = ModuleRenderer::new("hostname")
+            .config(toml::toml! {
+                [hostname]
+                ssh_only = false
+                trim_at = ""
+                detect_env_vars = ["!NEGATED_ONE", "!NEGATED_TWO", "!NEGATED_THREE"]
+            })
+            .collect();
+
+        let expected = Some(format!("{} in ", style().paint(hostname)));
+        assert_eq!(expected, actual);
+    }
+
+    #[test]
+    fn ssh_only_false_with_matching_env_var() {
+        let hostname = get_hostname!();
+        let actual = ModuleRenderer::new("hostname")
+            .config(toml::toml! {
+                [hostname]
+                ssh_only = false
+                trim_at = ""
+                detect_env_vars = ["FORCE_HOSTNAME"]
+            })
+            .env("FORCE_HOSTNAME", "true")
+            .collect();
+
+        let expected = Some(format!("{} in ", style().paint(hostname)));
+        assert_eq!(expected, actual);
+    }
+
+    #[test]
+    fn ssh_only_false_without_matching_env_vars() {
+        let actual = ModuleRenderer::new("hostname")
+            .config(toml::toml! {
+                [hostname]
+                ssh_only = false
+                trim_at = ""
+                detect_env_vars = ["FORCE_HOSTNAME", "!NEGATED"]
+            })
+            .collect();
+        let expected = None;
+
         assert_eq!(expected, actual);
     }
 
@@ -121,6 +190,7 @@ mod tests {
             })
             .collect();
         let expected = Some(format!("{} in ", style().paint(hostname)));
+
         assert_eq!(expected, actual);
     }
 
